============
Bag of Words
============

.. figure:: icons/bagofwords.png

Generates a bag of words from the input corpus.

Signals
-------

**Inputs**:

-  **Corpus**

Corpus instance.

**Outputs**:

-  **Corpus**

A set of words from corpus.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
